Index: Source/core/workers/WorkerLoaderProxy.h |
diff --git a/Source/core/workers/WorkerLoaderProxy.h b/Source/core/workers/WorkerLoaderProxy.h |
index ac5bc48aa2c69636babb79cde1fe9395f37bdf00..3342d900d77d41fea9a1288247dedb8d38ec683a 100644 |
--- a/Source/core/workers/WorkerLoaderProxy.h |
+++ b/Source/core/workers/WorkerLoaderProxy.h |
@@ -53,10 +53,10 @@ namespace WebCore { |
// Posts a task to the thread which runs the loading code (normally, the main thread). |
virtual void postTaskToLoader(PassOwnPtr<ScriptExecutionContext::Task>) = 0; |
// Posts callbacks from loading code to the WorkerContext. The 'mode' is used to differentiate |
// specific synchronous loading requests so they can be 'nested', per spec. |
// Returns true if the task was posted successfully. |
- virtual bool postTaskForModeToWorkerContext(PassOwnPtr<ScriptExecutionContext::Task>, const String& mode) = 0; |
+ virtual bool postTaskForModeToWorkerGlobalScope(PassOwnPtr<ScriptExecutionContext::Task>, const String& mode) = 0; |
// Spans divergent class hierarchies for dedicated and shared workers. |
virtual WebKit::WebWorkerBase* toWebWorkerBase() = 0; |
@@ -53,10 +53,10 @@ namespace WebCore { |
// Posts a task to the thread which runs the loading code (normally, the main thread). |
virtual void postTaskToLoader(PassOwnPtr<ScriptExecutionContext::Task>) = 0; |
- // Posts callbacks from loading code to the WorkerContext. The 'mode' is used to differentiate |
+ // Posts callbacks from loading code to the WorkerGlobalScope. The 'mode' is used to differentiate |
// specific synchronous loading requests so they can be 'nested', per spec. |
// Returns true if the task was posted successfully. |